@@ -153,7 +153,7 @@ SEXP R_H5Sdecode(SEXP R_buf){
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Sencode(hid_t obj_id, void *buf, size_t *nalloc); */
+/* H5_DLL herr_t H5Sencode1(hid_t obj_id, void *buf, size_t *nalloc); */
 SEXP R_H5Sencode(SEXP R_obj_id, SEXP R_buf, SEXP R_nalloc, SEXP _dupl_buf){
   hsize_t size_helper;
   SEXP R_helper = R_NilValue;
@@ -715,6 +715,28 @@ SEXP R_H5Sis_simple(SEXP R_space_id){
   return(__ret_list);
 }
 
+/* H5_DLL herr_t H5Smodify_select(hid_t space1_id, H5S_seloper_t op, hid_t space2_id); */
+SEXP R_H5Smodify_select(SEXP R_space1_id, SEXP R_op, SEXP R_space2_id){
+  int vars_protected=0;
+  hid_t space1_id = SEXP_to_longlong(R_space1_id, 0);
+  H5S_seloper_t op = SEXP_to_longlong(R_op, 0);
+  hid_t space2_id = SEXP_to_longlong(R_space2_id, 0);
+  herr_t return_val = H5Smodify_select(space1_id, op, space2_id);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
 /* H5_DLL herr_t H5Soffset_simple(hid_t space_id, const hssize_t *offset); */
 SEXP R_H5Soffset_simple(SEXP R_space_id, SEXP R_offset){
   SEXP R_helper = R_NilValue;
@@ -745,6 +767,166 @@ SEXP R_H5Soffset_simple(SEXP R_space_id, SEXP R_offset){
   return(__ret_list);
 }
 
+/* H5_DLL herr_t H5Ssel_iter_close(hid_t sel_iter_id); */
+SEXP R_H5Ssel_iter_close(SEXP R_sel_iter_id){
+  int vars_protected=0;
+  hid_t sel_iter_id = SEXP_to_longlong(R_sel_iter_id, 0);
+  herr_t return_val = H5Ssel_iter_close(sel_iter_id);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
+/* H5_DLL hid_t H5Ssel_iter_create(hid_t spaceid, size_t elmt_size, unsigned flags); */
+SEXP R_H5Ssel_iter_create(SEXP R_spaceid, SEXP R_elmt_size, SEXP R_flags){
+  int vars_protected=0;
+  hid_t spaceid = SEXP_to_longlong(R_spaceid, 0);
+  size_t elmt_size = SEXP_to_longlong(R_elmt_size, 0);
+  unsigned flags = SEXP_to_longlong(R_flags, 0);
+  hid_t return_val = H5Ssel_iter_create(spaceid, elmt_size, flags);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
+/* H5_DLL herr_t H5Ssel_iter_get_seq_list(hid_t sel_iter_id, size_t maxseq, size_t maxbytes, size_t *nseq, size_t *nbytes, hsize_t *off, size_t *len); */
+SEXP R_H5Ssel_iter_get_seq_list(SEXP R_sel_iter_id, SEXP R_maxseq, SEXP R_maxbytes, SEXP R_nseq, SEXP R_nbytes, SEXP R_off, SEXP R_len){
+  hsize_t size_helper;
+  SEXP R_helper = R_NilValue;
+  int vars_protected=0;
+  R_nseq = PROTECT(duplicate(R_nseq));
+  vars_protected++;
+  R_nbytes = PROTECT(duplicate(R_nbytes));
+  vars_protected++;
+  R_off = PROTECT(duplicate(R_off));
+  vars_protected++;
+  R_len = PROTECT(duplicate(R_len));
+  vars_protected++;
+  hid_t sel_iter_id = SEXP_to_longlong(R_sel_iter_id, 0);
+  size_t maxseq = SEXP_to_longlong(R_maxseq, 0);
+  size_t maxbytes = SEXP_to_longlong(R_maxbytes, 0);
+  size_t* nseq;
+  if(XLENGTH(R_nseq) == 0) {
+    nseq = NULL;
+  }
+  else {
+    R_helper = PROTECT(RToH5(R_nseq, h5_datatype[DT_size_t], XLENGTH(R_nseq)));
+    nseq= (size_t*) VOIDPTR(R_helper);
+    vars_protected++;
+  }
+  size_t* nbytes;
+  if(XLENGTH(R_nbytes) == 0) {
+    nbytes = NULL;
+  }
+  else {
+    R_helper = PROTECT(RToH5(R_nbytes, h5_datatype[DT_size_t], XLENGTH(R_nbytes)));
+    nbytes= (size_t*) VOIDPTR(R_helper);
+    vars_protected++;
+  }
+  hsize_t* off;
+  if(XLENGTH(R_off) == 0) {
+    off = NULL;
+  }
+  else {
+    R_helper = PROTECT(RToH5(R_off, h5_datatype[DT_hsize_t], XLENGTH(R_off)));
+    off= (hsize_t*) VOIDPTR(R_helper);
+    vars_protected++;
+  }
+  size_t* len;
+  if(XLENGTH(R_len) == 0) {
+    len = NULL;
+  }
+  else {
+    R_helper = PROTECT(RToH5(R_len, h5_datatype[DT_size_t], XLENGTH(R_len)));
+    len= (size_t*) VOIDPTR(R_helper);
+    vars_protected++;
+  }
+  herr_t return_val = H5Ssel_iter_get_seq_list(sel_iter_id, maxseq, maxbytes, nseq, nbytes, off, len);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  size_helper = guess_nelem(R_nseq, h5_datatype[DT_size_t]);
+  R_nseq = PROTECT(H5ToR_single_step(nseq, h5_datatype[DT_size_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
+  vars_protected++;
+  size_helper = guess_nelem(R_nbytes, h5_datatype[DT_size_t]);
+  R_nbytes = PROTECT(H5ToR_single_step(nbytes, h5_datatype[DT_size_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
+  vars_protected++;
+  size_helper = guess_nelem(R_off, h5_datatype[DT_hsize_t]);
+  R_off = PROTECT(H5ToR_single_step(off, h5_datatype[DT_hsize_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
+  vars_protected++;
+  size_helper = guess_nelem(R_len, h5_datatype[DT_size_t]);
+  R_len = PROTECT(H5ToR_single_step(len, h5_datatype[DT_size_t], size_helper, H5TOR_CONV_INT64_NOLOSS));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 5));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SET_VECTOR_ELT(__ret_list, 1, R_nseq);
+  SET_VECTOR_ELT(__ret_list, 2, R_nbytes);
+  SET_VECTOR_ELT(__ret_list, 3, R_off);
+  SET_VECTOR_ELT(__ret_list, 4, R_len);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 5));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_STRING_ELT(__ret_list_names, 1, mkChar("nseq"));
+  SET_STRING_ELT(__ret_list_names, 2, mkChar("nbytes"));
+  SET_STRING_ELT(__ret_list_names, 3, mkChar("off"));
+  SET_STRING_ELT(__ret_list_names, 4, mkChar("len"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
+/* H5_DLL herr_t H5Sselect_adjust(hid_t spaceid, const hssize_t *offset); */
+SEXP R_H5Sselect_adjust(SEXP R_spaceid, SEXP R_offset){
+  SEXP R_helper = R_NilValue;
+  int vars_protected=0;
+  hid_t spaceid = SEXP_to_longlong(R_spaceid, 0);
+  const hssize_t* offset;
+  if(XLENGTH(R_offset) == 0) {
+    offset = NULL;
+  }
+  else {
+    R_helper = PROTECT(RToH5(R_offset, h5_datatype[DT_hssize_t], XLENGTH(R_offset)));
+    offset= (const hssize_t*) VOIDPTR(R_helper);
+    vars_protected++;
+  }
+  herr_t return_val = H5Sselect_adjust(spaceid, offset);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
 /* H5_DLL herr_t H5Sselect_all(hid_t spaceid); */
 SEXP R_H5Sselect_all(SEXP R_spaceid){
   int vars_protected=0;
@@ -765,6 +947,27 @@ SEXP R_H5Sselect_all(SEXP R_spaceid){
   return(__ret_list);
 }
 
+/* H5_DLL herr_t H5Sselect_copy(hid_t dst_id, hid_t src_id); */
+SEXP R_H5Sselect_copy(SEXP R_dst_id, SEXP R_src_id){
+  int vars_protected=0;
+  hid_t dst_id = SEXP_to_longlong(R_dst_id, 0);
+  hid_t src_id = SEXP_to_longlong(R_src_id, 0);
+  herr_t return_val = H5Sselect_copy(dst_id, src_id);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
 /* H5_DLL herr_t H5Sselect_elements(hid_t space_id, H5S_seloper_t op, size_t num_elem, const hsize_t *coord); */
 SEXP R_H5Sselect_elements(SEXP R_space_id, SEXP R_op, SEXP R_num_elem, SEXP R_coord){
   SEXP R_helper = R_NilValue;
@@ -855,6 +1058,45 @@ SEXP R_H5Sselect_hyperslab(SEXP R_space_id, SEXP R_op, SEXP R_start, SEXP R__str
   return(__ret_list);
 }
 
+/* H5_DLL htri_t H5Sselect_intersect_block(hid_t space_id, const hsize_t *start, const hsize_t *end); */
+SEXP R_H5Sselect_intersect_block(SEXP R_space_id, SEXP R_start, SEXP R_end){
+  SEXP R_helper = R_NilValue;
+  int vars_protected=0;
+  hid_t space_id = SEXP_to_longlong(R_space_id, 0);
+  const hsize_t* start;
+  if(XLENGTH(R_start) == 0) {
+    start = NULL;
+  }
+  else {
+    R_helper = PROTECT(RToH5(R_start, h5_datatype[DT_hsize_t], XLENGTH(R_start)));
+    start= (const hsize_t*) VOIDPTR(R_helper);
+    vars_protected++;
+  }
+  const hsize_t* end;
+  if(XLENGTH(R_end) == 0) {
+    end = NULL;
+  }
+  else {
+    R_helper = PROTECT(RToH5(R_end, h5_datatype[DT_hsize_t], XLENGTH(R_end)));
+    end= (const hsize_t*) VOIDPTR(R_helper);
+    vars_protected++;
+  }
+  htri_t return_val = H5Sselect_intersect_block(space_id, start, end);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
 /* H5_DLL herr_t H5Sselect_none(hid_t spaceid); */
 SEXP R_H5Sselect_none(SEXP R_spaceid){
   int vars_protected=0;
@@ -875,6 +1117,49 @@ SEXP R_H5Sselect_none(SEXP R_spaceid){
   return(__ret_list);
 }
 
+/* H5_DLL hid_t H5Sselect_project_intersection(hid_t src_space_id, hid_t dst_space_id, hid_t src_intersect_space_id); */
+SEXP R_H5Sselect_project_intersection(SEXP R_src_space_id, SEXP R_dst_space_id, SEXP R_src_intersect_space_id){
+  int vars_protected=0;
+  hid_t src_space_id = SEXP_to_longlong(R_src_space_id, 0);
+  hid_t dst_space_id = SEXP_to_longlong(R_dst_space_id, 0);
+  hid_t src_intersect_space_id = SEXP_to_longlong(R_src_intersect_space_id, 0);
+  hid_t return_val = H5Sselect_project_intersection(src_space_id, dst_space_id, src_intersect_space_id);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
+/* H5_DLL htri_t H5Sselect_shape_same(hid_t space1_id, hid_t space2_id); */
+SEXP R_H5Sselect_shape_same(SEXP R_space1_id, SEXP R_space2_id){
+  int vars_protected=0;
+  hid_t space1_id = SEXP_to_longlong(R_space1_id, 0);
+  hid_t space2_id = SEXP_to_longlong(R_space2_id, 0);
+  htri_t return_val = H5Sselect_shape_same(space1_id, space2_id);
+  SEXP R_return_val= R_NilValue;
+  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
+  vars_protected++;
+  SEXP __ret_list;
+  PROTECT(__ret_list = allocVector(VECSXP, 1));
+  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
+  SEXP __ret_list_names;
+  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
+  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
+  SET_NAMES(__ret_list, __ret_list_names);
+  vars_protected += 2;
+  UNPROTECT(vars_protected);
+  return(__ret_list);
+}
+
 /* H5_DLL htri_t H5Sselect_valid(hid_t spaceid); */
 SEXP R_H5Sselect_valid(SEXP R_spaceid){
   int vars_protected=0;
